#!/usr/bin/env python
"""
A single Surface with multiple rectangles is a SpriteSheet. Each
rectangle can be extracted individually as a sprite, or the rectangles
can be used as anchor-points for grafting together sprites. This utility
is an editor for SpriteSheets
(C) Copyright 2004 James Paige & Hamster Republic Productions

This file is part of Open Leaping Lemmings.
http://HamsterRepublic.com/games/leaping/

Open Leaping Lemmings is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as published
by the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

Open Leaping Lemmings is distributed in the hope that it will be fun,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Open Leaping Lemmings in the file license.txt ;
if not, write to the Free Software Foundation, Inc.,
59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
"""

########################################################################

# standard libraries
import os
import sys
# pygame libraries
import pygame
from pygame.locals import *
# local libraries
import loader
import textsprite
from spritesheet import SpriteSheet

########################################################################

class SpriteSheetEd:
    """The main SpriteSheetEd editor class, which encapsulates
       the editor GUI"""
    
    def __init__(self):
        # init pygame
        pygame.init()
        # init screen mode, create window
        self.setWindow((640,480))
        pygame.display.set_caption('SpriteSheetEd')
        self.screenRect = self.screen.get_rect()
        # set up data location (for font)
        self.data = os.path.join(os.path.dirname(sys.argv[0]),'data')
        # instantiate data file reader
        self.loader = loader.DataDirReader(self.data)
        # load font
        self.font = self.loader.font('verasans.ttf',12)
        # create a clock for timing control
        self.clock = pygame.time.Clock()

    def setWindow(self,size):
        self.screen = pygame.display.set_mode(size,DOUBLEBUF)

    def quit(self):
        self.playing = 0

    def play(self):
        self.playing = 1
        while self.playing:
            # speed control
            self.clock.tick(32)
            # user input
            self.control()
            # game state update
            # screen update
            #self.paint()
        # end of play loop

    def control(self):
        for event in pygame.event.get():
            if event.type == QUIT:
                self.quit()
            elif event.type == KEYDOWN:
                if event.key == K_ESCAPE:
                    self.quit()

########################################################################

if __name__ == '__main__':
    # Import Psyco if available
    try:
        import psyco
        psyco.full()
    except ImportError:
        pass
    # instantiate and start editor object
    editor = SpriteSheetEd()
    editor.play()
